==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Grafikansicht</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Farben</translation>
    </message>
</context>
<context>
    <name>Colors</name>
    <message>
        <source>Colors</source>
        <translation type="obsolete">Farben</translation>
    </message>
    <message>
        <source>Graphics View</source>
        <translation type="obsolete">Grafikansicht</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <source>Selection:</source>
        <translation type="obsolete">Auswahl:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Grafikansicht</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Hintergrund:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Zeiger</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Inactive crosshairs:</source>
        <translation>Inaktives Fadenkreuz:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Ursprung</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Relativer Nullpunkt:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Raster</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Meta Raster:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Selektion</translation>
    </message>
    <message>
        <source>First selection color:</source>
        <translation type="obsolete">Erste Farbe für Selektion:</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Primäre Farbe für Selektion:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Sekundäre Farbe für Selektion verwenden</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Sekundäre Farbe für Selektion:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Referenzpunkte:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Sekundäre Referenzpunkte:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Auswahlbox (Rand):</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Auswahlbox:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Kreuzende Auswahlbox:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Snap Tools</source>
        <translation>Fangwerkzeuge</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Fang Hinweis:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Infowerkzeuge</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Masse und Beschriftung:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Zeichnungswerkzeuge</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Hilfsobjekte:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Zoomwerkzeuge</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Auswahlbox (Rand):</translation>
    </message>
    <message>
        <source>Crosshair:</source>
        <translation type="obsolete">Fadenkreuz:</translation>
    </message>
    <message>
        <source>Crosshair Inactive:</source>
        <translation type="obsolete">Inaktives Fadenkreuz:</translation>
    </message>
    <message>
        <source>Cross hair:</source>
        <translation type="obsolete">Fadenkreuz:</translation>
    </message>
    <message>
        <source>Cross hair Inactive:</source>
        <translation type="obsolete">Inaktives Fadenkreuz:</translation>
    </message>
    <message>
        <location line="-643"/>
        <source>Crosshairs:</source>
        <translation>Fadenkreuz:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translation type="obsolete">Inaktives Fadenkreuz:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Origin:</source>
        <translation>Nullpunkt:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translation type="obsolete">Relativer Nullpunkt:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">Referenzpunkt:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translation>Raster:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">Meta Raster:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translation type="obsolete">Zoombox:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translation type="obsolete">Auswahlbox (Rand):</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translation type="obsolete">Auswahlbox:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translation type="obsolete">Kreuzende Auswahlbox:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translation type="obsolete">Hilfsobjekte:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translation type="obsolete">Hintergrund Info Beschriftung:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translation type="obsolete">Schrift Info Beschriftung:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translation type="obsolete">Messwerkzeuge:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Grafikansicht</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Farben</translation>
    </message>
</context>
<context>
    <name>Colors</name>
    <message>
        <source>Colors</source>
        <translation type="obsolete">Farben</translation>
    </message>
    <message>
        <source>Graphics View</source>
        <translation type="obsolete">Grafikansicht</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <source>Selection:</source>
        <translation type="obsolete">Auswahl:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Grafikansicht</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Hintergrund:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Zeiger</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Inactive crosshairs:</source>
        <translation>Inaktives Fadenkreuz:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Ursprung</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Relativer Nullpunkt:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Raster</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Meta Raster:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Selektion</translation>
    </message>
    <message>
        <source>First selection color:</source>
        <translation type="obsolete">Erste Farbe für Selektion:</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Primäre Farbe für Selektion:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Sekundäre Farbe für Selektion verwenden</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Sekundäre Farbe für Selektion:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Referenzpunkte:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Sekundäre Referenzpunkte:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Auswahlbox (Rand):</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Auswahlbox:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Kreuzende Auswahlbox:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Start points:</source>
        <translation>Startpunkte:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End points:</source>
        <translation>Endpunkte:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Snap Tools</source>
        <translation>Fangwerkzeuge</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Fang Hinweis:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Infowerkzeuge</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Masse und Beschriftung:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Zeichnungswerkzeuge</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Hilfsobjekte:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Zoomwerkzeuge</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Auswahlbox (Rand):</translation>
    </message>
    <message>
        <source>Crosshair:</source>
        <translation type="obsolete">Fadenkreuz:</translation>
    </message>
    <message>
        <source>Crosshair Inactive:</source>
        <translation type="obsolete">Inaktives Fadenkreuz:</translation>
    </message>
    <message>
        <source>Cross hair:</source>
        <translation type="obsolete">Fadenkreuz:</translation>
    </message>
    <message>
        <source>Cross hair Inactive:</source>
        <translation type="obsolete">Inaktives Fadenkreuz:</translation>
    </message>
    <message>
        <location line="-697"/>
        <source>Crosshairs:</source>
        <translation>Fadenkreuz:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translation type="obsolete">Inaktives Fadenkreuz:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Origin:</source>
        <translation>Nullpunkt:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translation type="obsolete">Relativer Nullpunkt:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">Referenzpunkt:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translation>Raster:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">Meta Raster:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translation type="obsolete">Zoombox:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translation type="obsolete">Auswahlbox (Rand):</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translation type="obsolete">Auswahlbox:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translation type="obsolete">Kreuzende Auswahlbox:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translation type="obsolete">Hilfsobjekte:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translation type="obsolete">Hintergrund Info Beschriftung:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translation type="obsolete">Schrift Info Beschriftung:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translation type="obsolete">Messwerkzeuge:</translation>
    </message>
</context>
</TS>
